aboutsummaryrefslogtreecommitdiffstats
path: root/os/hal/lib/peripherals/flash
diff options
context:
space:
mode:
authorGiovanni Di Sirio <gdisirio@gmail.com>2016-05-07 15:44:55 +0000
committerGiovanni Di Sirio <gdisirio@gmail.com>2016-05-07 15:44:55 +0000
commit77ea39c0dfe2fb48118b5a876e914e4bc93d9ea4 (patch)
tree97262c058592b3727a4558a712c1fbd9e3396071 /os/hal/lib/peripherals/flash
parente8776f2fc57cd8f9808fb463a37dd468cfcbc2b6 (diff)
downloadChibiOS-77ea39c0dfe2fb48118b5a876e914e4bc93d9ea4.tar.gz
ChibiOS-77ea39c0dfe2fb48118b5a876e914e4bc93d9ea4.tar.bz2
ChibiOS-77ea39c0dfe2fb48118b5a876e914e4bc93d9ea4.zip
git-svn-id: svn://svn.code.sf.net/p/chibios/svn/trunk@9447 35acf78f-673a-0410-8e92-d51de3d6d3f4
Diffstat (limited to 'os/hal/lib/peripherals/flash')
-rw-r--r--os/hal/lib/peripherals/flash/hal_flash.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/os/hal/lib/peripherals/flash/hal_flash.h b/os/hal/lib/peripherals/flash/hal_flash.h
index 9905abb2a..736fbb201 100644
--- a/os/hal/lib/peripherals/flash/hal_flash.h
+++ b/os/hal/lib/peripherals/flash/hal_flash.h
@@ -36,6 +36,7 @@
#define FLASH_ATTR_ERASED_IS_ONE 0x00000001
#define FLASH_ATTR_MEMORY_MAPPED 0x00000002
#define FLASH_ATTR_REWRITABLE 0x00000004
+#define FLASH_ATTR_READ_ECC_CAPABLE 0x00000008
/** @} */
/*===========================================================================*/
@@ -57,8 +58,9 @@ typedef enum {
FLASH_NO_ERROR = 0, /* No error. */
FLASH_PARAMETER_ERROR = 1, /* Error in a function parameter. */
FLASH_ADDRESS_ERROR = 2, /* Operation overlaps invalid addresses. */
- FLASH_VERIFY_FAILURE = 3, /* Write or erase operation failed. */
- FLASH_HW_FAILURE = 4 /* Controller or communication error. */
+ FLASH_ECC_ERROR = 3, /* ECC error during read operation. */
+ FLASH_VERIFY_FAILURE = 4, /* Write or erase operation failed. */
+ FLASH_HW_FAILURE = 5 /* Controller or communication error. */
} flash_error_t;
/**